==> nextcloud-27.1.2.tgz: nextcloud/apps/files_reminders/l10n/fi.js <==
OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "Tiedostomuistutukset",
    "Reminder for {name}" : "Muistutus kohteesta {name}",
    "View file" : "Näytä tiedosto",
    "View folder" : "Näytä kansio",
    "Set file reminders" : "Aseta tiedostomuistutuksia",
    "**📣 File reminders**\n\nSet file reminders." : "**📣 Tiedostomuistutukset**\n\nAseta tiedostomuistutuksia.",
    "Back" : "Takaisin",
    "Clear reminder" : "Tyhjennä muistutus",
    "Set custom reminder" : "Aseta mukautettu muistutus",
    "Later today" : "Myöhemmin tänään",
    "Set reminder for later today" : "Aseta muistutus myöhemmälle ajankohdalle tälle päivälle",
    "Tomorrow" : "Huomenna",
    "Set reminder for tomorrow" : "Aseta muistutus huomiselle",
    "This weekend" : "Tämä viikonloppu",
    "Set reminder for this weekend" : "Aseta muistutus tälle viikonlopulle",
    "Next week" : "Seuraava viikko",
    "Set reminder for next week" : "Aseta muistutus seuraavalle viikolle",
    "Set reminder at custom date & time" : "Aseta muistutus mukautetulle päivälle ja ajankohdalle",
    "Reminder set for \"{fileName}\"" : "Muistutus asetettu tiedostolle \"{fileName}\"",
    "Failed to set reminder" : "Muistutuksen asettaminen epäonnistui",
    "Please choose a valid date & time" : "Valitse kelvollinen päivä ja aika",
    "Reminder cleared" : "Muistutus tyhjennetty",
    "Failed to clear reminder" : "Muistutuksen tyhjentäminen epäonnistui",
    "Failed to load reminder" : "Muistutuksen lataaminen epäonnistui"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-27.1.11.tgz: nextcloud/apps/files_reminders/l10n/fi.js <==
OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "Tiedostomuistutukset",
    "Reminder for {name}" : "Muistutus kohteesta {name}",
    "View file" : "Näytä tiedosto",
    "View folder" : "Näytä kansio",
    "Set file reminders" : "Aseta tiedostomuistutuksia",
    "**📣 File reminders**\n\nSet file reminders." : "**📣 Tiedostomuistutukset**\n\nAseta tiedostomuistutuksia.",
    "We will remind you of this file" : "Muistutamme sinua tästä tiedostosta",
    "Please choose a valid date & time" : "Valitse kelvollinen päivä ja aika",
    "Cancel" : "Peruuta",
    "Clear reminder" : "Tyhjennä muistutus",
    "Set reminder" : "Aseta muistutus",
    "Set reminder for \"{fileName}\"" : "Muistutus asetettu tiedostolle \"{fileName}\"",
    "Set reminder at custom date & time" : "Aseta muistutus mukautetulle päivälle ja ajankohdalle",
    "Reminder set for \"{fileName}\"" : "Muistutus asetettu tiedostolle \"{fileName}\"",
    "Failed to set reminder" : "Muistutuksen asettaminen epäonnistui",
    "Failed to clear reminder" : "Muistutuksen tyhjentäminen epäonnistui",
    "Reminder set" : "Muistutus asetettu",
    "Set custom reminder" : "Aseta mukautettu muistutus",
    "Later today" : "Myöhemmin tänään",
    "Set reminder for later today" : "Aseta muistutus myöhemmälle ajankohdalle tälle päivälle",
    "Tomorrow" : "Huomenna",
    "Set reminder for tomorrow" : "Aseta muistutus huomiselle",
    "This weekend" : "Tämä viikonloppu",
    "Set reminder for this weekend" : "Aseta muistutus tälle viikonlopulle",
    "Next week" : "Seuraava viikko",
    "Set reminder for next week" : "Aseta muistutus seuraavalle viikolle",
    "Back" : "Takaisin",
    "Reminder cleared" : "Muistutus tyhjennetty",
    "Failed to load reminder" : "Muistutuksen lataaminen epäonnistui"
},
"nplurals=2; plural=(n != 1);");
